@@ -1,5 +1,4 @@
 #include "cpu.h"
-#include "detection/temps/temps_windows.h"
 #include "util/windows/registry.h"
 #include "util/windows/nt.h"
 #include "util/mallocHelper.h"
@@ -101,9 +100,7 @@ static const char* detectNCores(FFCPUResult* cpu)
         ptr = (SYSTEM_LOGICAL_PROCESSOR_INFORMATION_EX*)(((uint8_t*)ptr) + ptr->Size)
     )
     {
-        if (ptr->Relationship == RelationProcessorCore)
-            ++cpu->coresPhysical;
-        else if (ptr->Relationship == RelationGroup)
+        if (ptr->Relationship == RelationGroup)
         {
             for (uint32_t index = 0; index < ptr->Group.ActiveGroupCount; ++index)
             {
@@ -111,6 +108,10 @@ static const char* detectNCores(FFCPUResult* cpu)
                 cpu->coresLogical += ptr->Group.GroupInfo[index].MaximumProcessorCount;
             }
         }
+        else if (ptr->Relationship == RelationProcessorCore)
+            ++cpu->coresPhysical;
+        else if (ptr->Relationship == RelationProcessorPackage)
+            cpu->packages++;
     }
 
     return NULL;
@@ -160,6 +161,8 @@ static const char* detectCoreTypes(FFCPUResult* cpu)
     return NULL;
 }
 
+const char* detectThermalTemp(double* current, double* critical);
+
 const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
 {
     detectNCores(cpu);
@@ -175,7 +178,7 @@ const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
         detectMaxSpeedBySmbios(cpu);
 
     if(options->temp)
-        ffDetectSmbiosTemp(&cpu->temperature, NULL);
+        detectThermalTemp(&cpu->temperature, NULL);
 
     return NULL;
 }
