@@ -95,7 +95,7 @@ const char* ffDetectEditor(FFEditorResult* result)
 
     if (ffStrbufEqualS(&result->exe, "nvim"))
         ffBinaryExtractStrings(result->path.chars, extractNvimVersionFromBinary, &result->version, (uint32_t) strlen("NVIM v0.0.0"));
-    else if (ffStrbufEqualS(&result->exe, "vim"))
+    else if (ffStrbufEqualS(&result->exe, "vim") || ffStrbufStartsWithS(&result->exe, "vim."))
         ffBinaryExtractStrings(result->path.chars, extractVimVersionFromBinary, &result->version, (uint32_t) strlen("VIM - Vi IMproved 0.0"));
     else if (ffStrbufEqualS(&result->exe, "nano"))
         ffBinaryExtractStrings(result->path.chars, extractNanoVersionFromBinary, &result->version, (uint32_t) strlen("GNU nano 0.0"));
@@ -106,6 +106,7 @@ const char* ffDetectEditor(FFEditorResult* result)
     if (
         ffStrbufEqualS(&result->exe, "nano") ||
         ffStrbufEqualS(&result->exe, "vim") ||
+        ffStrbufStartsWithS(&result->exe, "vim.") || // vim.basic/vim.tiny
         ffStrbufEqualS(&result->exe, "nvim") ||
         ffStrbufEqualS(&result->exe, "micro") ||
         ffStrbufEqualS(&result->exe, "emacs") ||
@@ -134,24 +135,14 @@ const char* ffDetectEditor(FFEditorResult* result)
         return NULL;
 
     ffStrbufSubstrBeforeFirstC(&result->version, '\n');
-    for (uint32_t iStart = 0; iStart < result->version.length; ++iStart)
-    {
-        char c = result->version.chars[iStart];
-        if (ffCharIsDigit(c))
-        {
-            for (uint32_t iEnd = iStart + 1; iEnd < result->version.length; ++iEnd)
-            {
-                char c = result->version.chars[iEnd];
-                if (isspace(c))
-                {
-                    ffStrbufSubstrBefore(&result->version, iEnd);
-                    break;
-                }
-            }
-            if (iStart > 0)
-                ffStrbufSubstrAfter(&result->version, iStart - 1);
-            break;
-        }
+    const char* versionStart = strpbrk(result->version.chars, "0123456789");
+    if (versionStart != NULL) {
+        const char* versionEnd = strpbrk(versionStart, " \t\v\f\r");
+        if (versionEnd != NULL)
+            ffStrbufSubstrBefore(&result->version, (uint32_t)(versionEnd - result->version.chars));
+
+        if (versionStart != result->version.chars)
+            ffStrbufSubstrAfter(&result->version, (uint32_t)(versionStart - result->version.chars - 1));
     }
 
     return NULL;
