@@ -6,7 +6,7 @@
 #include "modules/cpu/cpu.h"
 #include "util/stringUtils.h"
 
-#define FF_CPU_NUM_FORMAT_ARGS 9
+#define FF_CPU_NUM_FORMAT_ARGS 10
 
 static int sortCores(const FFCPUCore* a, const FFCPUCore* b)
 {
@@ -55,6 +55,9 @@ void ffPrintCPU(FFCPUOptions* options)
 
             FF_STRBUF_AUTO_DESTROY str = ffStrbufCreate();
 
+            if(cpu.packages > 1)
+                ffStrbufAppendF(&str, "%u x ", cpu.packages);
+
             if(cpu.name.length > 0)
                 ffStrbufAppend(&str, &cpu.name);
             else if(cpu.vendor.length > 0)
@@ -68,7 +71,12 @@ void ffPrintCPU(FFCPUOptions* options)
             if(coreTypes.length > 0)
                 ffStrbufAppendF(&str, " (%s)", coreTypes.chars);
             else if(cpu.coresOnline > 1)
-                ffStrbufAppendF(&str, " (%u)", cpu.coresOnline);
+            {
+                if(cpu.packages > 1)
+                    ffStrbufAppendF(&str, " (%u)", cpu.coresOnline / 2);
+                else
+                    ffStrbufAppendF(&str, " (%u)", cpu.coresOnline);
+            }
 
             uint32_t freq = cpu.frequencyMax;
             if(freq == 0)
@@ -106,6 +114,7 @@ void ffPrintCPU(FFCPUOptions* options)
                 FF_FORMAT_ARG(freqMax, "freq-max"),
                 FF_FORMAT_ARG(tempStr, "temperature"),
                 FF_FORMAT_ARG(coreTypes, "core-types"),
+                FF_FORMAT_ARG(cpu.packages, "packages"),
             }));
         }
     }
@@ -203,6 +212,10 @@ void ffGenerateCPUJsonResult(FFCPUOptions* options, yyjson_mut_doc* doc, yyjson_
         yyjson_mut_val* obj = yyjson_mut_obj_add_obj(doc, module, "result");
         yyjson_mut_obj_add_strbuf(doc, obj, "cpu", &cpu.name);
         yyjson_mut_obj_add_strbuf(doc, obj, "vendor", &cpu.vendor);
+        if (cpu.packages == 0)
+            yyjson_mut_obj_add_null(doc, obj, "packages");
+        else
+            yyjson_mut_obj_add_uint(doc, obj, "packages", cpu.packages);
 
         yyjson_mut_val* cores = yyjson_mut_obj_add_obj(doc, obj, "cores");
         yyjson_mut_obj_add_uint(doc, cores, "physical", cpu.coresPhysical);
@@ -240,6 +253,7 @@ void ffPrintCPUHelpFormat(void)
         "Max frequency (formatted) - freq-max",
         "Temperature (formatted) - temperature",
         "Logical core count grouped by frequency - core-types",
+        "Processor package count - packages",
     }));
 }
 
