@@ -65,15 +65,15 @@ bool ffEdidGetName(const uint8_t edid[128], FFstrbuf* name)
 
 void ffEdidGetPhysicalSize(const uint8_t edid[128], uint32_t* width, uint32_t* height)
 {
-    *width = (((uint32_t) edid[68] & 0xF0) << 4) + edid[66];
-    *height = (((uint32_t) edid[68] & 0x0F) << 8) + edid[67];
+    *width = edid[21] * 10;
+    *height = edid[22] * 10;
 }
 
 void ffEdidGetSerialAndManufactureDate(const uint8_t edid[128], uint32_t* serial, uint16_t* year, uint16_t* week)
 {
     if (edid[17] > 0 && edid[17] < 0xFF)
     {
-        *year = (uint16_t) edid[17] + 1990;
+        *year = (uint16_t) (edid[17] + 1990);
         *week = (uint16_t) edid[16];
         if (*week == 0xFF) *week = 0;
     }
